diff --git a/include/gepetto/gui/plugin-interface.hh b/include/gepetto/gui/plugin-interface.hh
index 0228cfd079722558b44355b01777031cdf1ebf45..5e5f2394aec6e0960d3c699a54a71cdb9edfb4b0 100644
--- a/include/gepetto/gui/plugin-interface.hh
+++ b/include/gepetto/gui/plugin-interface.hh
@@ -93,10 +93,10 @@ namespace gepetto {
   } // namespace gui
 } // namespace gepetto
 
-Q_DECLARE_INTERFACE (gepetto::gui::PluginInterface, "hpp-gui.plugins/0.0")
-Q_DECLARE_INTERFACE (gepetto::gui::JointModifierInterface, "hpp-gui.plugin.joint-modifier/0.0")
-Q_DECLARE_INTERFACE (gepetto::gui::ModelInterface, "hpp-gui.plugin.model/0.0")
-Q_DECLARE_INTERFACE (gepetto::gui::CorbaInterface, "hpp-gui.plugin.corba/0.0")
+Q_DECLARE_INTERFACE (gepetto::gui::PluginInterface, "gepetto-gui.plugins/0.0")
+Q_DECLARE_INTERFACE (gepetto::gui::JointModifierInterface, "gepetto-gui.plugin.joint-modifier/0.0")
+Q_DECLARE_INTERFACE (gepetto::gui::ModelInterface, "gepetto-gui.plugin.model/0.0")
+Q_DECLARE_INTERFACE (gepetto::gui::CorbaInterface, "gepetto-gui.plugin.corba/0.0")
 
 
 
diff --git a/include/gepetto/gui/pythonwidget.hh b/include/gepetto/gui/pythonwidget.hh
index ef9d40e6c96d835e225e5e09de48d2066528194d..1c8e4dd14f09647d0941f776854483e2d841426b 100644
--- a/include/gepetto/gui/pythonwidget.hh
+++ b/include/gepetto/gui/pythonwidget.hh
@@ -5,7 +5,7 @@
 #include <gepetto/gui/config-dep.hh>
 
 #if ! GEPETTO_GUI_HAS_PYTHONQT
-# error "hpp-gui was not compile with PythonQt dependency."
+# error "gepetto-viewer-corba was not compile with PythonQt dependency."
 #endif
 
 #include <QVariant>
diff --git a/include/gepetto/gui/ui/mainwindow.ui b/include/gepetto/gui/ui/mainwindow.ui
index cc2f2e0b83a6a4790f451eb122cc4a5351ce4622..83bb24ce95acabe7d84c4bb3b2101c2079fa6b59 100644
--- a/include/gepetto/gui/ui/mainwindow.ui
+++ b/include/gepetto/gui/ui/mainwindow.ui
@@ -11,7 +11,7 @@
    </rect>
   </property>
   <property name="windowTitle">
-   <string>HPP</string>
+   <string>Gepetto GUI</string>
   </property>
   <property name="windowIcon">
    <iconset theme="hpp-gui">
diff --git a/src/gui/settings.cc b/src/gui/settings.cc
index 8ff7bacbf58f8b41287fb588dbd16d8fe66e4ed7..c8e3b642b69d0c58568a1edfef313decf04b609c 100644
--- a/src/gui/settings.cc
+++ b/src/gui/settings.cc
@@ -1,18 +1,18 @@
 // Copyright (c) 2015, Joseph Mirabel
 // Authors: Joseph Mirabel (joseph.mirabel@laas.fr)
 //
 // This file is part of hpp-gui.
 // hpp-gui is free software: you can redistribute it
 // and/or modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation, either version
 // 3 of the License, or (at your option) any later version.
 //
-// hpp-gui is distributed in the hope that it will be
+// gepetto-viewer-corba is distributed in the hope that it will be
 // useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 // of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // General Lesser Public License for more details.  You should have
 // received a copy of the GNU Lesser General Public License along with
-// hpp-gui. If not, see <http://www.gnu.org/licenses/>.
+// gepetto-viewer-corba. If not, see <http://www.gnu.org/licenses/>.
 
 #include <gepetto/gui/settings.hh>
 
@@ -49,7 +49,7 @@ namespace gepetto {
       , mw (0)
     {
       QDir user (QDir::home());
-      const char path[] = "Pictures/hpp-gui";
+      const char path[] = "Pictures/gepetto-gui";
       user.mkpath (path);
       user.cd (path);
       captureDirectory = user.absolutePath().toStdString();
@@ -1,18 +1,18 @@
 // Authors: Joseph Mirabel (joseph.mirabel@laas.fr)
 //
-// This file is part of hpp-gui.
-// hpp-gui is free software: you can redistribute it
+// This file is part of gepetto-viewer-corba.
+// gepetto-viewer-corba is free software: you can redistribute it
 // and/or modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation, either version